@@ -41,6 +41,23 @@ CohortSubsetDefinition <- R6::R6Class(
     }
   ),
   public = list(
+    #' pretty in print
+    #'
+    #' @param ... further arguments passed to or from other methods.
+    print = function(...) {
+      cat(glue::glue("<Cohort Subset Defintion [{self$definitionId}]:\t{self$name}> \n\n"))
+      cat(glue::glue("\tIdentifier expression: \"{self$identifierExpression}\"\n\n"))
+      cat(glue::glue("\tNaming template: \"{self$subsetCohortNameTemplate}\"\n\n"))
+      cat(glue::glue("Contains {length(self$subsetOperators)} operations:"))
+      cat("\n")
+      cat("\n")
+      for (so in self$subsetOperators) {
+        print(so)
+        cat("\n")
+      }
+      cat("\n\n")
+    },
+
     #' @param definition  json or list representation of object
     initialize = function(definition = NULL) {
       if (!is.null(definition)) {
@@ -93,7 +110,8 @@ CohortSubsetDefinition <- R6::R6Class(
     #' Returns vector of join, logic, having statements returned by subset operations
     #' @param targetOutputPair              Target output pair
     getSubsetQuery = function(targetOutputPair) {
-      checkmate::assertIntegerish(targetOutputPair, len = 2)
+      checkmate::assertNumeric(targetOutputPair, len = 2)
+      checkmate::assertTRUE(all(targetOutputPair %% 1 == 0))
       checkmate::assertFALSE(targetOutputPair[[1]] == targetOutputPair[[2]])
 
       targetTable <- "#cohort_sub_base"
@@ -134,7 +152,8 @@ CohortSubsetDefinition <- R6::R6Class(
     #' @param cohortDefinitionSet           Cohort definition set containing base names
     #' @param targetOutputPair              Target output pair
     getSubsetCohortName = function(cohortDefinitionSet, targetOutputPair) {
-      checkmate::assertIntegerish(targetOutputPair, len = 2)
+      checkmate::assertNumeric(targetOutputPair, len = 2)
+      checkmate::assertTRUE(all(targetOutputPair %% 1 == 0))
       checkmate::assertFALSE(targetOutputPair[[1]] == targetOutputPair[[2]])
       checkmate::assertTRUE(targetOutputPair[[1]] %in% cohortDefinitionSet$cohortId)
       checkmate::assertTRUE(isCohortDefinitionSet(cohortDefinitionSet))
@@ -157,7 +176,9 @@ CohortSubsetDefinition <- R6::R6Class(
     #' Set the targetOutputPairs to be added to a cohort definition set
     #' @param targetIds   list of cohort ids to apply subsetting operations to
     setTargetOutputPairs = function(targetIds) {
-      checkmate::assertIntegerish(targetIds, min.len = 1, upper = 10e11)
+      checkmate::assertNumeric(targetIds, min.len = 1)
+      checkmate::assertTRUE(all(targetIds %% 1 == 0))
+
       definitionId <- self$definitionId
       targetOutputPairs <- list()
 
@@ -191,7 +212,8 @@ CohortSubsetDefinition <- R6::R6Class(
         targetOutputPairs,
         function(targetOutputPair) {
           targetOutputPair <- as.numeric(targetOutputPair)
-          checkmate::assertIntegerish(targetOutputPair, len = 2, upper = 10e11)
+          checkmate::assertNumeric(targetOutputPair, len = 2)
+          checkmate::assertTRUE(all(targetOutputPair %% 1 == 0))
           checkmate::assertFALSE(targetOutputPair[[1]] == targetOutputPair[[2]])
           targetOutputPair
         }
@@ -305,23 +327,22 @@ CohortSubsetDefinition <- R6::R6Class(
 #' @param subsetOperators           list of subsetOperator instances to apply
 #' @param identifierExpression      Expression (or string that converts to expression) that returns an id for an output cohort
 #'                                  the default is dplyr::expr(targetId * 1000 + definitionId)
-#' @param subsetCohortNameTemplate  (optional) SqlRender string template for formatting names of resulting subset cohorts
-#'                                  Can use the variables @baseCohortName, @subsetDefinitionName and @operatorNames.
+#' @param subsetCohortNameTemplate  SqlRender string template for formatting names of resulting subset cohorts
+#'                                  Can use the variables @baseCohortName and @subsetDefinitionName.
 #'                                  This is applied when adding the subset definition to a cohort definition set.
-#' @param operatorNameConcatString  (optional) String to concatenate operator names together when outputting resulting cohort
-#'                                   name
 createCohortSubsetDefinition <- function(name,
                                          definitionId,
                                          subsetOperators,
                                          identifierExpression = NULL,
-                                         operatorNameConcatString = "",
-                                         subsetCohortNameTemplate = "") {
+                                         subsetCohortNameTemplate = "@baseCohortName - @subsetDefinitionName") {
+  checkmate::assertString(name, min.chars = 1)
   subsetDef <- CohortSubsetDefinition$new()
   subsetDef$name <- name
   subsetDef$definitionId <- definitionId
   subsetDef$subsetOperators <- subsetOperators
   subsetDef$identifierExpression <- identifierExpression
-  subsetDef$operatorNameConcatString <- operatorNameConcatString
+  # Set to default to support consistent json serialization with class
+  subsetDef$operatorNameConcatString <- ""
   subsetDef$subsetCohortNameTemplate <- subsetCohortNameTemplate
   return(subsetDef)
 }
@@ -357,6 +378,10 @@ addCohortSubsetDefinition <- function(cohortDefinitionSet,
     cohortDefinitionSet$isSubset <- FALSE
   }
 
+  if (!"isTemplatedCohort" %in% colnames(cohortDefinitionSet)) {
+    cohortDefinitionSet$isTemplatedCohort <- FALSE
+  }
+
   if (!is.null(targetCohortIds)) {
     checkmate::assertSubset(targetCohortIds, cohortDefinitionSet$cohortId)
   } else {
@@ -434,6 +459,7 @@ addCohortSubsetDefinition <- function(cohortDefinitionSet,
           cohortName = subsetCohortName,
           subsetParent = toPair[1],
           isSubset = TRUE,
+          isTemplatedCohort = FALSE,
           sql = subsetSql,
           json = as.character(.toJSON(repr)),
           subsetDefinitionId = subsetDefinitionCopy$definitionId
