@@ -281,6 +281,23 @@ SubsetOperator <- R6::R6Class(
     #' @return list representation of object as json character
     toJSON = function() {
       .toJSON(self$toList())
+    },
+
+    #' Pretty print
+    #'
+    #' @param ...   further arguments passed to or from other methods.
+    print = function(...) {
+      cat(glue::glue("*** {self$classname()} ***"))
+      cat("\n")
+      if (!is.null(private$.name)) {
+        cat(self$name)
+        cat("\n")
+      }
+      cat(self$getAutoGeneratedName())
+      cat("\n")
+      cat("SQL: ")
+      qb <- self$getQueryBuilder(1)
+      print(qb)
     }
   ),
   active = list(
@@ -446,7 +463,7 @@ CohortSubsetOperator <- R6::R6Class(
 # createCohortSubset ------------------------------
 #' A definition of subset functions to be applied to a set of cohorts
 #' @export
-#'
+#' @family subsets
 #' @param name  optional name of operator
 #' @param cohortIds integer - set of cohort ids to subset to
 #' @param cohortCombinationOperator "any" or "all" if using more than one cohort id allow a subject to be in any cohort
@@ -460,7 +477,7 @@ CohortSubsetOperator <- R6::R6Class(
 #'                                  these windows.
 #' @param negate                    The opposite of this definition - include patients who do NOT meet the specified criteria
 #' @returns a CohortSubsetOperator instance
-createCohortSubset <- function(name = NULL, cohortIds, cohortCombinationOperator, negate, windows = list(), startWindow = NULL, endWindow = NULL) {
+createCohortSubsetOperator <- function(name = NULL, cohortIds, cohortCombinationOperator, negate, windows = list(), startWindow = NULL, endWindow = NULL) {
   subset <- CohortSubsetOperator$new()
   subset$name <- name
   subset$cohortIds <- cohortIds
@@ -702,8 +719,9 @@ DemographicSubsetOperator <- R6::R6Class(
 )
 
 # createDemographicSubset ------------------------------
-#' Create createDemographicSubset Subset
+#' Create createDemographicSubset Subset operator
 #' @export
+#' @family subsets
 #' @param name         Optional char name
 #' @param ageMin       The minimum age
 #' @param ageMax       The maximum age
@@ -713,7 +731,7 @@ DemographicSubsetOperator <- R6::R6Class(
 #'                     Specific concept ids not in this set can be used but are not explicitly validated
 #' @param race         Race demographics - concept ID list
 #' @param ethnicity    Ethnicity demographics - concept ID list
-createDemographicSubset <- function(name = NULL, ageMin = 0, ageMax = 99999, gender = NULL, race = NULL, ethnicity = NULL) {
+createDemographicSubsetOperator <- function(name = NULL, ageMin = 0, ageMax = 99999, gender = NULL, race = NULL, ethnicity = NULL) {
   mapGenderCodes <- function(x) {
     if (length(x) > 1) {
       retValue <- c()
@@ -764,6 +782,7 @@ LimitSubsetOperator <- R6::R6Class(
     .priorTime = 0,
     .followUpTime = 0,
     .minimumCohortDuration = 0,
+    .maximumCohortDuration = NULL,
     .limitTo = character(0),
     .calendarStartDate = NULL,
     .calendarEndDate = NULL
@@ -810,6 +829,10 @@ LimitSubsetOperator <- R6::R6Class(
         nameString <- paste(nameString, "lasting at least", self$minimumCohortDuration, "days")
       }
 
+      if (!is.null(self$maximumCohortDuration)) {
+        nameString <- paste(nameString, "lasting at most", self$maximumCohortDuration, "days")
+      }
+
       return(nameString)
     },
     #' To List
@@ -819,6 +842,7 @@ LimitSubsetOperator <- R6::R6Class(
       objRef$priorTime <- jsonlite::unbox(private$.priorTime)
       objRef$followUpTime <- jsonlite::unbox(private$.followUpTime)
       objRef$minimumCohortDuration <- jsonlite::unbox(private$.minimumCohortDuration)
+      objRef$maximumCohortDuration <- jsonlite::unbox(private$.maximumCohortDuration)
       objRef$limitTo <- jsonlite::unbox(private$.limitTo)
       objRef$calendarStartDate <- jsonlite::unbox(private$.calendarStartDate)
       objRef$calendarEndDate <- jsonlite::unbox(private$.calendarEndDate)
@@ -856,7 +880,20 @@ LimitSubsetOperator <- R6::R6Class(
       private$.minimumCohortDuration <- duration
       self
     },
-
+    #' @field maximumCohortDuration            maximum cohort duration time in days
+    maximumCohortDuration = function(duration) {
+      if (missing(duration)) {
+        return(private$.maximumCohortDuration)
+      }
+      if (is.null(duration)) {
+        private$.maximumCohortDuration <- NULL
+        return(self)
+      } else {
+        checkmate::assertInt(duration, lower = 0, upper = 99999)
+        private$.maximumCohortDuration <- duration
+        self
+      }
+    },
     #' @field limitTo     character one of:
     #'                              "firstEver" - only first entry in patient history
     #'                              "earliestRemaining" - only first entry after washout set by priorTime
@@ -896,6 +933,11 @@ LimitSubsetOperator <- R6::R6Class(
         }
       }
       checkmate::assertDate(calendarStartDate, null.ok = TRUE)
+
+      if (length(calendarStartDate) && is.na(calendarStartDate)) {
+        stop("Must provide a valid date, not NA")
+      }
+
       private$.calendarStartDate <- calendarStartDate
       self
     },
@@ -913,6 +955,11 @@ LimitSubsetOperator <- R6::R6Class(
         }
       }
       checkmate::assertDate(calendarEndDate, null.ok = TRUE)
+
+      if (length(calendarEndDate) && is.na(calendarEndDate)) {
+        stop("Must provide a valid date, not NA")
+      }
+
       private$.calendarEndDate <- calendarEndDate
       self
     }
@@ -920,14 +967,16 @@ LimitSubsetOperator <- R6::R6Class(
 )
 
 # createLimitSubset ------------------------------
-#' Create Limit Subset
+#' Create Limit Subset Operator
 #' @description
 #' Subset cohorts using specified limit criteria
 #' @export
+#' @family subsets
 #' @param name                  Name of operation
 #' @param priorTime             Required prior observation window (specified as a positive integer)
 #' @param followUpTime          Required post observation window (specified as a positive integer)
 #' @param minimumCohortDuration Required cohort duration length (specified as a positive integer)
+#' @param maximumCohortDuration Optional: maximum cohort duration length (specified as a positive integer), defaults to NULL
 #' @param limitTo           character one of:
 #'                              "firstEver" - only first entry in patient history
 #'                              "earliestRemaining" - only first entry after washout set by priorTime
@@ -940,18 +989,20 @@ LimitSubsetOperator <- R6::R6Class(
 #'                          criteria are applied (i.e. after applying prior/post time and calendar time).
 #' @param calendarEndDate       Start date to allow period (e.g. 2015/1/1)
 #' @param calendarStartDate     End date to allow periods (e.g. 2020/1/1/)
-createLimitSubset <- function(name = NULL,
-                              priorTime = 0,
-                              followUpTime = 0,
-                              minimumCohortDuration = 0,
-                              limitTo = "all",
-                              calendarStartDate = NULL,
-                              calendarEndDate = NULL) {
+createLimitSubsetOperator <- function(name = NULL,
+                                      priorTime = 0,
+                                      followUpTime = 0,
+                                      minimumCohortDuration = 0,
+                                      maximumCohortDuration = NULL,
+                                      limitTo = "all",
+                                      calendarStartDate = NULL,
+                                      calendarEndDate = NULL) {
   if (limitTo == "" || is.null(limitTo)) {
     limitTo <- "all"
   }
 
-  if (minimumCohortDuration == 0 && priorTime == 0 & followUpTime == 0 & limitTo == "all" & is.null(calendarStartDate) & is.null(calendarEndDate)) {
+  if (minimumCohortDuration == 0 && priorTime == 0 & followUpTime == 0 & limitTo == "all" &
+    is.null(maximumCohortDuration) & is.null(calendarStartDate) & is.null(calendarEndDate)) {
     stop("No limit criteria specified")
   }
 
@@ -960,9 +1011,43 @@ createLimitSubset <- function(name = NULL,
   subset$priorTime <- priorTime
   subset$followUpTime <- followUpTime
   subset$minimumCohortDuration <- minimumCohortDuration
+  subset$maximumCohortDuration <- maximumCohortDuration
   subset$limitTo <- limitTo
   subset$calendarStartDate <- calendarStartDate
   subset$calendarEndDate <- calendarEndDate
 
   subset
 }
+
+#' Create Limit Subset Operator
+#' @description
+#' Subset cohorts using specified limit criteria.
+#' deprecated This function is deprecated. Please use `createLimitSubsetOperator()` instead.
+#' @param ... Arguments passed to the underlying operator.
+#' @export
+createLimitSubset <- function(...) {
+  .Deprecated("createLimitSubsetOperator")
+  createLimitSubsetOperator(...)
+}
+
+#' Create Cohort Subset Operator
+#' @description
+#' Subset cohorts using specified limit criteria.
+#' deprecated This function is deprecated. Please use `createCohortSubsetOperator()` instead.
+#' @param ... Arguments passed to the underlying operator.
+#' @export
+createCohortSubset <- function(...) {
+  .Deprecated("createLimitSubsetOperator")
+  createCohortSubsetOperator(...)
+}
+
+#' Create Demographic Subset Operator
+#' @description
+#' Subset cohorts using specified limit criteria.
+#' deprecated This function is deprecated. Please use `createDemographicSubsetOperator()` instead.
+#' @param ... Arguments passed to the underlying operator.
+#' @export
+createDemographicSubset <- function(...) {
+  .Deprecated("createLimitSubsetOperator")
+  createDemographicSubsetOperator(...)
+}
